from django.urls import path
from ottoboni.contact import views

urlpatterns = [
    path('obrigado/', views.ContactSuccess.as_view(), name='contact_success'),
    path('', views.Contact.as_view(), name='contact'),
]



# -*- coding: utf-8 -*-
# Generated by Django 1.9.2 on 2016-04-06 00:55
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('contact', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='Contact',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=100, verbose_name='Nome')),
                ('email', models.EmailField(max_length=254, verbose_name='Email')),
                ('tel_prefix', models.IntegerField(verbose_name='DDD')),
                ('tel', models.IntegerField(verbose_name='Telefone')),
                ('tel_sufix', models.IntegerField(blank=True, null=True, verbose_name='Ramal')),
                ('company', models.CharField(blank=True, max_length=100, null=True, verbose_name='Empresa')),
                ('postal', models.IntegerField(verbose_name='CEP')),
                ('state', models.CharField(max_length=200, verbose_name='Estado')),
                ('city', models.CharField(max_length=200, verbose_name='Cidade')),
                ('district', models.CharField(max_length=200, verbose_name='Bairro')),
                ('address', models.CharField(max_length=200, verbose_name='Endereço')),
                ('address_number', models.IntegerField(blank=True, null=True, verbose_name='Número')),
                ('address_complement', models.CharField(blank=True, max_length=200, null=True, verbose_name='Complemento')),
                ('message', models.TextField(verbose_name='Mensagem')),
                ('created_at', models.DateTimeField(auto_now_add=True, verbose_name='Enviado em')),
                ('device', models.CharField(blank=True, max_length=100, null=True, verbose_name='Dispositivo')),
            ],
            options={
                'verbose_name_plural': 'Contatos',
                'verbose_name': 'Contato',
            },
        ),
        migrations.CreateModel(
            name='Profession',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(max_length=100)),
            ],
            options={
                'verbose_name_plural': 'Áreas de atuação',
                'verbose_name': 'Área de atuação',
            },
        ),
        migrations.CreateModel(
            name='Subject',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(max_length=100)),
            ],
            options={
                'verbose_name_plural': 'Assuntos',
                'verbose_name': 'Assunto',
            },
        ),
        migrations.DeleteModel(
            name='Press',
        ),
        migrations.DeleteModel(
            name='Video',
        ),
        migrations.AddField(
            model_name='contact',
            name='profession',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='contacts', to='contact.Profession', verbose_name='Área de atuação'),
        ),
        migrations.AddField(
            model_name='contact',
            name='subject',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='contacts', to='contact.Subject', verbose_name='Assunto'),
        ),
    ]



from django.db import models


class Profession(models.Model):
    def __str__(self):
        return str(self.title)

    title = models.CharField(max_length=100)

    class Meta:
        verbose_name = 'Área de atuação'
        verbose_name_plural = 'Áreas de atuação'


class Subject(models.Model):
    def __str__(self):
        return str(self.title)

    title = models.CharField(max_length=100)
    is_active = models.BooleanField(verbose_name='Ativo?', default=True)
    order = models.IntegerField('Ordem', null=True, blank=True, default=0)

    class Meta:
        verbose_name = 'Assunto'
        verbose_name_plural = 'Assuntos'


class Contact(models.Model):
    def __str__(self):
        return str(self.email)

    name = models.CharField('Nome', max_length=100)
    email = models.EmailField('Email')
    tel_prefix = models.IntegerField('DDD')
    tel = models.CharField('Telefone', max_length=11)
    tel_sufix = models.IntegerField('Ramal', null=True, blank=True)
    company = models.CharField('Empresa', max_length=100, null=True, blank=True)
    profession = models.ForeignKey(
        Profession,
        verbose_name='Área de atuação',
        related_name='contacts',
        null=True,
        blank=True,
        on_delete=models.SET_NULL,
    )
    postal = models.IntegerField('CEP', null=True, blank=True)
    state = models.CharField('Estado', max_length=200, null=True, blank=True)
    city = models.CharField('Cidade', max_length=200, null=True, blank=True)
    district = models.CharField('Bairro', max_length=200, null=True, blank=True)
    address = models.CharField('Endereço', max_length=200, null=True, blank=True)
    address_number = models.IntegerField('Número', null=True, blank=True)
    address_complement = models.CharField(
        'Complemento', max_length=200, null=True, blank=True
    )
    subject = models.ForeignKey(
        Subject,
        verbose_name='Assunto',
        related_name='contacts',
        on_delete=models.CASCADE,
    )
    message = models.TextField('Mensagem')
    created_at = models.DateTimeField('Enviado em', auto_now_add=True)
    device = models.CharField('Dispositivo', max_length=100, null=True, blank=True)
    its_budget = models.BooleanField('É um orçamento?', default=False)

    class Meta:
        verbose_name = 'Contato'
        verbose_name_plural = 'Contatos'



# -*- coding: utf-8 -*-
# Generated by Django 1.9.2 on 2018-10-16 14:00
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('contact', '0002_auto_20160405_2155'),
    ]

    operations = [
        migrations.AddField(
            model_name='subject',
            name='is_active',
            field=models.BooleanField(default=True, verbose_name='Ativo?'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.29 on 2021-01-05 16:48
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('contact', '0006_auto_20191008_1416'),
    ]

    operations = [
        migrations.AddField(
            model_name='subject',
            name='order',
            field=models.IntegerField(null=True, verbose_name='Ordem'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.29 on 2021-01-05 16:53
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('contact', '0007_subject_order'),
    ]

    operations = [
        migrations.AlterField(
            model_name='subject',
            name='order',
            field=models.IntegerField(default=0, null=True, verbose_name='Ordem'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.9.2 on 2019-09-06 13:20
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('contact', '0004_auto_20190814_1713'),
    ]

    operations = [
        migrations.AddField(
            model_name='contact',
            name='its_budget',
            field=models.BooleanField(default=False, verbose_name='É um orçamento?'),
        ),
    ]



import os
from typing import List

from django.core.management.base import BaseCommand


class AutodocCommandUtils(BaseCommand):
    """
    Classe utilitária para gerar diagramas de classes e funções.
    """

    def process_app(self, app_name: str):
        """
        Encontra os caminhos dos arquivos e gera diagramas.
        """
        # Arquivos a serem analisados
        app_path = self.get_app_path(app_name)
        views_path = os.path.join(app_path, 'views')
        admin_path = os.path.join(app_path, 'admin')
        tasks_path = os.path.join(app_path, 'tasks')

        # Gera documentação se os arquivos existirem
        if os.path.isdir(views_path):
            for file in os.listdir(views_path):
                if not file.startswith('__') and file.endswith('.py'):
                    self.generate_views_diagram(
                        os.path.join(views_path, file), app_name
                    )
        elif os.path.exists(f'{views_path}.py'):
            self.generate_views_diagram(f'{views_path}.py', app_name)

        if os.path.isdir(admin_path):
            for file in os.listdir(admin_path):
                if not file.startswith('__') and file.endswith('.py'):
                    self.generate_admin_diagram(
                        os.path.join(admin_path, file), app_name
                    )
        elif os.path.exists(f'{admin_path}.py'):
            self.generate_admin_diagram(f'{admin_path}.py', app_name)

        if os.path.isdir(tasks_path):
            for file in os.listdir(tasks_path):
                if not file.startswith('__') and file.endswith('.py'):
                    self.generate_tasks_diagram(
                        os.path.join(tasks_path, file), app_name
                    )
        elif os.path.exists(f'{tasks_path}.py'):
            self.generate_tasks_diagram(f'{tasks_path}.py', app_name)

    def get_app_path(self, app_name: str):
        """Retorna o caminho do app Django."""
        module = __import__(app_name)
        if not module.__file__:
            raise ValueError(
                f'Não foi possível encontrar o caminho para o app {app_name}'
            )
        return os.path.dirname(module.__file__)

    def save_mermaid_diagram(self, mermaid_code: List[str], filename: str):
        """Salva o diagrama Mermaid em um arquivo."""
        if not self.validate_mermaid_code(mermaid_code):
            self.stdout.write(
                self.style.ERROR(
                    f'Diagrama Mermaid não existe para o arquivo: {filename}'
                )
            )
            return
        output_dir = 'docs/mermaid/flow'
        os.makedirs(output_dir, exist_ok=True)

        filepath = f'{output_dir}/{filename}.md'
        with open(filepath, 'w') as f:
            f.write('\n'.join(mermaid_code))
            f.write('\n```')

        self.stdout.write(
            self.style.SUCCESS(f'Diagrama Mermaid gerado com sucesso: {filepath}')
        )

    def validate_mermaid_code(self, mermaid_code: List[str]):
        """Validate inner code of mermaid diagram."""
        return bool(mermaid_code[2:])

    def generate_views_diagram(self, path, app_name):
        raise NotImplementedError

    def generate_admin_diagram(self, path, app_name):
        raise NotImplementedError

    def generate_tasks_diagram(self, path, app_name):
        raise NotImplementedError



from django.conf import settings
from django.contrib import messages
from django.core.mail import send_mail
from django.views.generic import View
from django.views.generic.edit import FormView
from django.shortcuts import render
from ottoboni.contact import forms
from ottoboni.contact import models
from ottoboni.core.flags import STATE_CHOICES


class Contact(FormView):
    template_name = 'contact.html'
    form_class = forms.ContactForm
    success_url = 'obrigado'

    def get_initial(self):
        if self.request.GET:
            initial = self.request.GET.dict()
            return initial
        else:
            return super(Contact, self).get_initial()

    def get_context_data(self, **kwargs):
        context = super(Contact, self).get_context_data(**kwargs)
        context['professions'] = models.Profession.objects.all()
        context['subjects'] = models.Subject.objects.filter(is_active=True).order_by('order')
        context['states'] = STATE_CHOICES
        return context

    def form_valid(self, form):
        form.save()
        body = 'Nome: {} <br>\
        Email: <a href="{}" target="_blank">{}</a><br>\
        Telefone: ({}) {} Ramal: {}<br>\
        Empresa: {} <br>\
        Área de atuação: {} <br>\
        CEP: {} <br>\
        Endereço: {}, Número {} {}, {} - {}, {} <br>\
        Assunto: {} <br>\
        Mensagem: {} <br>\
        Dispositivo: {}'.format(
            form.cleaned_data.get('name') or 'Não informado',
            form.cleaned_data.get('email') or 'Não informado',
            form.cleaned_data.get('email') or 'Não informado',
            form.cleaned_data.get('tel_prefix') or 'Não informado',
            form.cleaned_data.get('tel') or 'Não informado',
            form.cleaned_data.get('tel_sufix') or 'Não informado',
            form.cleaned_data.get('company') or 'Não informado',
            form.cleaned_data.get('profession') or 'Não informado',
            form.cleaned_data.get('postal') or 'Não informado',
            form.cleaned_data.get('address') or 'Não informado',
            form.cleaned_data.get('address_number') or 'Não informado',
            form.cleaned_data.get('address_complement') or '',
            form.cleaned_data.get('district') or 'Não informado',
            form.cleaned_data.get('city') or 'Não informado',
            form.cleaned_data.get('state') or 'Não informado',
            form.cleaned_data.get('subject') or 'Não informado',
            form.cleaned_data.get('message') or 'Não informado',
            form.cleaned_data.get('device') or 'Não detectado',
        )

        send_mail(
            'Contato do site',
            'Seguem os dados do cliente',
            settings.DEFAULT_FROM_EMAIL,
            settings.ADMINS_CONTATO,
            html_message=body,
            fail_silently=False,
        )

        return super(Contact, self).form_valid(form)


class ContactSuccess(View):
    def get(self, request):
        context = {'show_google_conversion': not settings.DEV}
        # context = { 'show_google_conversion': not settings.DEBUG }
        return render(request, 'success.html', context)



from django import forms
from ottoboni.contact import models
from ottoboni.core.flags import STATE_CHOICES


class ContactForm(forms.ModelForm):

    subject = forms.ModelChoiceField(queryset=models.Subject.objects.none(), empty_label='Assunto')
    profession = forms.ModelChoiceField(queryset=models.Profession.objects.all(), empty_label='Área de atuação', required=False)
    postal = forms.CharField()
    state = forms.ChoiceField(label='Estado', choices=STATE_CHOICES)

    class Meta:
        model = models.Contact
        exclude = ['created_at']

    def __init__(self, *args, **kwargs):
        super(ContactForm, self).__init__(*args, **kwargs)
        self.fields['subject'].queryset = models.Subject.objects.filter(is_active=True).order_by('order')

    def clean_postal(self):
        postal = self.cleaned_data['postal']
        postal = postal.replace('-', '')
        return postal



# -*- coding: utf-8 -*-
# Generated by Django 1.9.2 on 2019-10-08 17:16
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('contact', '0005_contact_its_budget'),
    ]

    operations = [
        migrations.AlterField(
            model_name='contact',
            name='tel',
            field=models.CharField(max_length=11, verbose_name='Telefone'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.9.2 on 2019-08-14 20:13
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('contact', '0003_subject_is_active'),
    ]

    operations = [
        migrations.AlterField(
            model_name='contact',
            name='address',
            field=models.CharField(blank=True, max_length=200, null=True, verbose_name='Endereço'),
        ),
        migrations.AlterField(
            model_name='contact',
            name='city',
            field=models.CharField(blank=True, max_length=200, null=True, verbose_name='Cidade'),
        ),
        migrations.AlterField(
            model_name='contact',
            name='district',
            field=models.CharField(blank=True, max_length=200, null=True, verbose_name='Bairro'),
        ),
        migrations.AlterField(
            model_name='contact',
            name='postal',
            field=models.IntegerField(blank=True, null=True, verbose_name='CEP'),
        ),
        migrations.AlterField(
            model_name='contact',
            name='state',
            field=models.CharField(blank=True, max_length=200, null=True, verbose_name='Estado'),
        ),
    ]



import setuptools

with open('README.md', 'r', encoding='utf-8') as fh:
    long_description = fh.read()

setuptools.setup(
    name='autodoc-django',
    version='0.1.0',
    author='Marcos Gomes',
    author_email='gomes.marcosjf@gmail.com',
    description="Provide an automatic documentation for Django's Apps",
    long_description=long_description,
    long_description_content_type='text/markdown',
    url='https://github.com/GomesMarcos/autodoc-django',
    packages=setuptools.find_packages(),
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
    python_requires='>=3.6',
    install_requires=[
        'asgiref>=3.8.1',
        'Django>=4.2.19',
        'python-decouple>=3.8',
        'ruff>=0.7.1',
        'sqlparse>=0.5.1',
    ],
)



# -*- coding: utf-8 -*-
# Generated by Django 1.9.2 on 2016-04-06 00:53
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Press',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(blank=True, max_length=100, null=True, verbose_name='Título')),
                ('desc', models.TextField(verbose_name='Descrição')),
                ('image', models.ImageField(upload_to='/vagrant/application/uploads/clipping', verbose_name='Imagem')),
                ('order', models.IntegerField(null=True, unique=True, verbose_name='Ordem')),
            ],
            options={
                'ordering': ('order',),
                'verbose_name': 'Matéria',
                'verbose_name_plural': 'Matérias',
            },
        ),
        migrations.CreateModel(
            name='Video',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(blank=True, max_length=100, null=True, verbose_name='Título')),
                ('desc', models.TextField(verbose_name='Descrição')),
                ('video', models.URLField(unique=True, verbose_name='URL do Youtube')),
                ('order', models.IntegerField(null=True, unique=True, verbose_name='Ordem')),
            ],
            options={
                'ordering': ('order',),
                'verbose_name': 'Vídeo',
                'verbose_name_plural': 'Vídeos',
            },
        ),
    ]



from django.contrib import admin
from django.utils.safestring import mark_safe
from . import models
import csv
from django.http import HttpResponse

@admin.register(models.Contact)
class ContactAdmin(admin.ModelAdmin):
    list_display = ['name', 'email', 'tel_str', 'address_str', 'subject', 'message', 'profession', 'device',
                    'created_at', 'its_budget']
    ordering = ('-created_at', )
    search_fields = ('name', 'email', 'tel', 'city')
    list_filter = ('subject', 'profession', 'device', 'its_budget')
    actions = ['export_as_csv']

    def tel_str(self, obj):
        return '({}) {}'.format(obj.tel_prefix, obj.tel)
    tel_str.short_description = 'Telefone'

    def address_str(self, obj):
        text = 'Rua: <strong>{}</strong> | Bairro: <strong>{}</strong> | Nº <strong>{}</strong> | Complemento: <strong>{}</strong> | Cidade/Estado: <strong>{}/{}</strong>'.format(
            obj.address or '-', obj.district or '-', obj.address_number or '-', obj.address_complement or '-', obj.city or '-', obj.state or '-')

        return mark_safe(text)
    address_str.short_description = 'Endereço'

    def export_as_csv(self, request, queryset):

        meta = self.model._meta
        field_names = [field.name for field in meta.fields]

        response = HttpResponse(content_type='text/csv')
        response['Content-Disposition'] = 'attachment; filename={}.csv'.format(meta)
        writer = csv.writer(response)

        writer.writerow(field_names)
        for obj in queryset:
            row = writer.writerow([getattr(obj, field) for field in field_names])

        return response
    export_as_csv.short_description = "Exportar para CSV"


@admin.register(models.Profession)
class ProfessionAdmin(admin.ModelAdmin):
    list_display = ('title', )
    ordering = ('title', )
    search_fields = ('title', )


@admin.register(models.Subject)
class SubjectAdmin(admin.ModelAdmin):
    list_display = ('title', 'order', 'is_active')
    ordering = ['order']
    search_fields = ('title', )
    list_editable = ['order']



# Generated by Django 3.2.11 on 2024-01-17 22:33

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('contact', '0009_auto_20210105_1354'),
    ]

    operations = [
        migrations.AlterField(
            model_name='contact',
            name='id',
            field=models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID'),
        ),
        migrations.AlterField(
            model_name='contact',
            name='profession',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='contacts', to='contact.profession', verbose_name='Área de atuação'),
        ),
        migrations.AlterField(
            model_name='profession',
            name='id',
            field=models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID'),
        ),
        migrations.AlterField(
            model_name='subject',
            name='id',
            field=models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID'),
        ),
    ]
